# flake8: noqa

# import apis into api package
from lance_namespace_urllib3_client.api.data_api import DataApi
from lance_namespace_urllib3_client.api.index_api import IndexApi
from lance_namespace_urllib3_client.api.metadata_api import MetadataApi
from lance_namespace_urllib3_client.api.namespace_api import NamespaceApi
from lance_namespace_urllib3_client.api.table_api import TableApi
from lance_namespace_urllib3_client.api.tag_api import TagApi
from lance_namespace_urllib3_client.api.transaction_api import TransactionApi




# coding: utf-8

"""
    Lance Namespace Specification

    This OpenAPI specification is a part of the Lance namespace specification. It contains 2 parts:  The `components/schemas`, `components/responses`, `components/examples`, `tags` sections define the request and response shape for each operation in a Lance Namespace across all implementations. See https://lancedb.github.io/lance-namespace/spec/operations for more details.  The `servers`, `security`, `paths`, `components/parameters` sections are for the  Lance REST Namespace implementation, which defines a complete REST server that can work with Lance datasets. See https://lancedb.github.io/lance-namespace/spec/impls/rest for more details. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from lance_namespace_urllib3_client.api.data_api import DataApi


class TestDataApi(unittest.TestCase):
    """DataApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DataApi()

    def tearDown(self) -> None:
        pass

    def test_alter_table_add_columns(self) -> None:
        """Test case for alter_table_add_columns

        Add new columns to table schema
        """
        pass

    def test_analyze_table_query_plan(self) -> None:
        """Test case for analyze_table_query_plan

        Analyze query execution plan
        """
        pass

    def test_count_table_rows(self) -> None:
        """Test case for count_table_rows

        Count rows in a table
        """
        pass

    def test_create_table(self) -> None:
        """Test case for create_table

        Create a table with the given name
        """
        pass

    def test_delete_from_table(self) -> None:
        """Test case for delete_from_table

        Delete rows from a table
        """
        pass

    def test_explain_table_query_plan(self) -> None:
        """Test case for explain_table_query_plan

        Get query execution plan explanation
        """
        pass

    def test_insert_into_table(self) -> None:
        """Test case for insert_into_table

        Insert records into a table
        """
        pass

    def test_merge_insert_into_table(self) -> None:
        """Test case for merge_insert_into_table

        Merge insert (upsert) records into a table
        """
        pass

    def test_query_table(self) -> None:
        """Test case for query_table

        Query a table
        """
        pass

    def test_update_table(self) -> None:
        """Test case for update_table

        Update rows in a table
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Lance Namespace Specification

    This OpenAPI specification is a part of the Lance namespace specification. It contains 2 parts:  The `components/schemas`, `components/responses`, `components/examples`, `tags` sections define the request and response shape for each operation in a Lance Namespace across all implementations. See https://lancedb.github.io/lance-namespace/spec/operations for more details.  The `servers`, `security`, `paths`, `components/parameters` sections are for the  Lance REST Namespace implementation, which defines a complete REST server that can work with Lance datasets. See https://lancedb.github.io/lance-namespace/spec/impls/rest for more details. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from lance_namespace_urllib3_client.api.metadata_api import MetadataApi


class TestMetadataApi(unittest.TestCase):
    """MetadataApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MetadataApi()

    def tearDown(self) -> None:
        pass

    def test_alter_table_alter_columns(self) -> None:
        """Test case for alter_table_alter_columns

        Modify existing columns
        """
        pass

    def test_alter_table_drop_columns(self) -> None:
        """Test case for alter_table_drop_columns

        Remove columns from table
        """
        pass

    def test_alter_transaction(self) -> None:
        """Test case for alter_transaction

        Alter information of a transaction.
        """
        pass

    def test_create_empty_table(self) -> None:
        """Test case for create_empty_table

        Create an empty table
        """
        pass

    def test_create_namespace(self) -> None:
        """Test case for create_namespace

        Create a new namespace
        """
        pass

    def test_create_table_index(self) -> None:
        """Test case for create_table_index

        Create an index on a table
        """
        pass

    def test_create_table_tag(self) -> None:
        """Test case for create_table_tag

        Create a new tag
        """
        pass

    def test_delete_table_tag(self) -> None:
        """Test case for delete_table_tag

        Delete a tag
        """
        pass

    def test_deregister_table(self) -> None:
        """Test case for deregister_table

        Deregister a table
        """
        pass

    def test_describe_namespace(self) -> None:
        """Test case for describe_namespace

        Describe a namespace
        """
        pass

    def test_describe_table(self) -> None:
        """Test case for describe_table

        Describe information of a table
        """
        pass

    def test_describe_table_index_stats(self) -> None:
        """Test case for describe_table_index_stats

        Get table index statistics
        """
        pass

    def test_describe_transaction(self) -> None:
        """Test case for describe_transaction

        Describe information about a transaction
        """
        pass

    def test_drop_namespace(self) -> None:
        """Test case for drop_namespace

        Drop a namespace
        """
        pass

    def test_drop_table(self) -> None:
        """Test case for drop_table

        Drop a table
        """
        pass

    def test_drop_table_index(self) -> None:
        """Test case for drop_table_index

        Drop a specific index
        """
        pass

    def test_get_table_stats(self) -> None:
        """Test case for get_table_stats

        Get table statistics
        """
        pass

    def test_get_table_tag_version(self) -> None:
        """Test case for get_table_tag_version

        Get version for a specific tag
        """
        pass

    def test_list_namespaces(self) -> None:
        """Test case for list_namespaces

        List namespaces
        """
        pass

    def test_list_table_indices(self) -> None:
        """Test case for list_table_indices

        List indexes on a table
        """
        pass

    def test_list_table_tags(self) -> None:
        """Test case for list_table_tags

        List all tags for a table
        """
        pass

    def test_list_table_versions(self) -> None:
        """Test case for list_table_versions

        List all versions of a table
        """
        pass

    def test_list_tables(self) -> None:
        """Test case for list_tables

        List tables in a namespace
        """
        pass

    def test_namespace_exists(self) -> None:
        """Test case for namespace_exists

        Check if a namespace exists
        """
        pass

    def test_register_table(self) -> None:
        """Test case for register_table

        Register a table to a namespace
        """
        pass

    def test_restore_table(self) -> None:
        """Test case for restore_table

        Restore table to a specific version
        """
        pass

    def test_table_exists(self) -> None:
        """Test case for table_exists

        Check if a table exists
        """
        pass

    def test_update_table_tag(self) -> None:
        """Test case for update_table_tag

        Update a tag to point to a different version
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Lance Namespace Specification

    This OpenAPI specification is a part of the Lance namespace specification. It contains 2 parts:  The `components/schemas`, `components/responses`, `components/examples`, `tags` sections define the request and response shape for each operation in a Lance Namespace across all implementations. See https://lancedb.github.io/lance-namespace/spec/operations for more details.  The `servers`, `security`, `paths`, `components/parameters` sections are for the  Lance REST Namespace implementation, which defines a complete REST server that can work with Lance datasets. See https://lancedb.github.io/lance-namespace/spec/impls/rest for more details. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict
from typing import Any, ClassVar, Dict, List, Optional
from lance_namespace_urllib3_client.models.match_query import MatchQuery
from lance_namespace_urllib3_client.models.multi_match_query import MultiMatchQuery
from lance_namespace_urllib3_client.models.phrase_query import PhraseQuery
from typing import Optional, Set
from typing_extensions import Self

class FtsQuery(BaseModel):
    """
    Full-text search query. Exactly one query type field must be provided. This structure follows the same pattern as AlterTransactionAction to minimize differences and compatibility issues across codegen in different languages. 
    """ # noqa: E501
    match: Optional[MatchQuery] = None
    phrase: Optional[PhraseQuery] = None
    boost: Optional[BoostQuery] = None
    multi_match: Optional[MultiMatchQuery] = None
    boolean: Optional[BooleanQuery] = None
    __properties: ClassVar[List[str]] = ["match", "phrase", "boost", "multi_match", "boolean"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FtsQuery from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of match
        if self.match:
            _dict['match'] = self.match.to_dict()
        # override the default output from pydantic by calling `to_dict()` of phrase
        if self.phrase:
            _dict['phrase'] = self.phrase.to_dict()
        # override the default output from pydantic by calling `to_dict()` of boost
        if self.boost:
            _dict['boost'] = self.boost.to_dict()
        # override the default output from pydantic by calling `to_dict()` of multi_match
        if self.multi_match:
            _dict['multi_match'] = self.multi_match.to_dict()
        # override the default output from pydantic by calling `to_dict()` of boolean
        if self.boolean:
            _dict['boolean'] = self.boolean.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FtsQuery from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "match": MatchQuery.from_dict(obj["match"]) if obj.get("match") is not None else None,
            "phrase": PhraseQuery.from_dict(obj["phrase"]) if obj.get("phrase") is not None else None,
            "boost": BoostQuery.from_dict(obj["boost"]) if obj.get("boost") is not None else None,
            "multi_match": MultiMatchQuery.from_dict(obj["multi_match"]) if obj.get("multi_match") is not None else None,
            "boolean": BooleanQuery.from_dict(obj["boolean"]) if obj.get("boolean") is not None else None
        })
        return _obj

from lance_namespace_urllib3_client.models.boolean_query import BooleanQuery
from lance_namespace_urllib3_client.models.boost_query import BoostQuery
# TODO: Rewrite to not use raise_errors
FtsQuery.model_rebuild(raise_errors=False)

